diff --git a/tests/check-apt-key.sh b/tests/check-apt-key.sh
index 993cc3e4d353d3982d00ddb31c28215a68448fda..47a752b664a9776bced1c46e175abe5682fafb61 100644
--- a/tests/check-apt-key.sh
+++ b/tests/check-apt-key.sh
@@ -2,12 +2,12 @@
 #Verify with the key fatch from https://ftp-master.debian.org/keys.html
 
 #---------------------------------------------------------------------------
 #"Debian Archive Automatic Signing Key (8/jessie) <ftpmaster@debian.org>"
 
-JESSIEARCHIVEKEY=" 126C 0D24 BD8A 2942 CC7D  F8AC 7638 D044 2B90 D010"
-CHECKTMP=$(apt-key finger | grep -B 1 "Debian Archive Automatic Signing Key (8/jessie) <ftpmaster@debian.org>" | head -n1 | awk -F '=' '{printf $2}')
+STRETCHARCHIVEKEY=" E1CF 20DD FFE4 B89E 8026  58F1 E0B1 1894 F66A EC98"
+CHECKTMP=$(apt-key finger | grep -B 1 "Debian Archive Automatic Signing Key (9/stretch) <ftpmaster@debian.org>" | head -n1 | awk -F '=' '{printf $2}')
 
-if [ "$CHECKTMP" == "$JESSIEARCHIVEKEY" ];then
+if [ "$CHECKTMP" == "$STRETCHARCHIVEKEY" ];then
        echo Good
        :
 else
@@ -16,12 +16,12 @@ else
 fi
 
 #---------------------------------------------------------------------------
 #"Debian Security Archive Automatic Signing Key (8/jessie) <ftpmaster@debian.org>"
 
-JESSIESECURITYKEY=" D211 6914 1CEC D440 F2EB  8DDA 9D6D 8F6B C857 C906"
-CHECKTMP=$(apt-key finger | grep -B 1 "Debian Security Archive Automatic Signing Key (8/jessie) <ftpmaster@debian.org>" | head -n1 | awk -F '=' '{printf $2}')
+STRETCHSECURITYKEY=" 6ED6 F5CB 5FA6 FB2F 460A  E88E EDA0 D238 8AE2 2BA9"
+CHECKTMP=$(apt-key finger | grep -B 1 "Debian Security Archive Automatic Signing Key (9/stretch) <ftpmaster@debian.org>" | head -n1 | awk -F '=' '{printf $2}')
 
-if [ "$CHECKTMP" == "$JESSIESECURITYKEY" ];then
+if [ "$CHECKTMP" == "$STRETCHSECURITYKEY" ];then
        echo Good
        :
 else
@@ -30,12 +30,26 @@ else
 fi
 
 #---------------------------------------------------------------------------
 #"Jessie Stable Release Key <debian-release@lists.debian.org>"
 
-JESSIESTABLEKEY=" 75DD C3C4 A499 F1A1 8CB5  F3C8 CBF8 D6FD 518E 17E1"
-CHECKTMP=$(apt-key finger | grep -B 1 "Jessie Stable Release Key <debian-release@lists.debian.org>" | head -n1 | awk -F '=' '{printf $2}')
+STRETCHSTABLEKEY=" 067E 3C45 6BAE 240A CEE8  8F6F EF0F 382A 1A7B 6500"
+CHECKTMP=$(apt-key finger | grep -B 1 "Debian Stable Release Key (9/stretch) <debian-release@lists.debian.org>" | head -n1 | awk -F '=' '{printf $2}')
 
-if [ "$CHECKTMP" == "$JESSIESTABLEKEY" ];then
+if [ "$CHECKTMP" == "$STRETCHSTABLEKEY" ];then
+       echo Good
+       :
+else
+       echo bad
+       exit 1
+fi
+
+#---------------------------------------------------------------------------
+#"Debian Archive Automatic Signing Key (8/jessie) <ftpmaster@debian.org>"
+
+JESSIEARCHIVEKEY=" 126C 0D24 BD8A 2942 CC7D  F8AC 7638 D044 2B90 D010"
+CHECKTMP=$(apt-key finger | grep -B 1 "Debian Archive Automatic Signing Key (8/jessie) <ftpmaster@debian.org>" | head -n1 | awk -F '=' '{printf $2}')
+
+if [ "$CHECKTMP" == "$JESSIEARCHIVEKEY" ];then
        echo Good
        :
 else
@@ -44,12 +58,12 @@ else
 fi
 
 #---------------------------------------------------------------------------
-#"Debian Archive Automatic Signing Key (6.0/squeeze) <ftpmaster@debian.org>"
+#"Debian Security Archive Automatic Signing Key (8/jessie) <ftpmaster@debian.org>"
 
-SQUEEZEARCHIVEKEY=" 9FED 2BCB DCD2 9CDF 7626  78CB AED4 B06F 4730 41FA"
-CHECKTMP=$(apt-key finger | grep -B 1 "Debian Archive Automatic Signing Key (6.0/squeeze) <ftpmaster@debian.org>" | head -n1 | awk -F '=' '{printf $2}')
+JESSIESECURITYKEY=" D211 6914 1CEC D440 F2EB  8DDA 9D6D 8F6B C857 C906"
+CHECKTMP=$(apt-key finger | grep -B 1 "Debian Security Archive Automatic Signing Key (8/jessie) <ftpmaster@debian.org>" | head -n1 | awk -F '=' '{printf $2}')
 
-if [ "$CHECKTMP" == "$SQUEEZEARCHIVEKEY" ];then
+if [ "$CHECKTMP" == "$JESSIESECURITYKEY" ];then
        echo Good
        :
 else
@@ -58,12 +72,12 @@ else
 fi
 
 #---------------------------------------------------------------------------
-#"Squeeze Stable Release Key <debian-release@lists.debian.org>"
+#"Jessie Stable Release Key <debian-release@lists.debian.org>"
 
-SQUEEZESTABLEKEY=" 0E4E DE2C 7F3E 1FC0 D033  800E 6448 1591 B983 21F9"
-CHECKTMP=$(apt-key finger | grep -B 1 "Squeeze Stable Release Key <debian-release@lists.debian.org>" | head -n1 | awk -F '=' '{printf $2}')
+JESSIESTABLEKEY=" 75DD C3C4 A499 F1A1 8CB5  F3C8 CBF8 D6FD 518E 17E1"
+CHECKTMP=$(apt-key finger | grep -B 1 "Jessie Stable Release Key <debian-release@lists.debian.org>" | head -n1 | awk -F '=' '{printf $2}')
 
-if [ "$CHECKTMP" == "$SQUEEZESTABLEKEY" ];then
+if [ "$CHECKTMP" == "$JESSIESTABLEKEY" ];then
        echo Good
        :
 else
@@ -2,12 +2,12 @@
 
 #---------------------------------------------------------------------------
-#"Debian Archive Automatic Signing Key (8/jessie) <ftpmaster@debian.org>"
+#"Debian Archive Automatic Signing Key (9/stretch) <ftpmaster@debian.org>"
 
@@ -16,12 +16,12 @@ else
 
 #---------------------------------------------------------------------------
-#"Debian Security Archive Automatic Signing Key (8/jessie) <ftpmaster@debian.org>"
+#"Debian Security Archive Automatic Signing Key (9/stretch) <ftpmaster@debian.org>"
 
@@ -30,12 +30,26 @@ else
 
 #---------------------------------------------------------------------------
-#"Jessie Stable Release Key <debian-release@lists.debian.org>"
+#"Debian Stable Release Key (9/stretch) <debian-release@lists.debian.org>"
 